@@ -79,7 +79,6 @@ import com.verisign.epp.codec.signedMark.EPPIssuer;
 import com.verisign.epp.codec.signedMark.EPPSignedMark;
 import com.verisign.epp.codec.signedMark.SMDRevocationList;
 import com.verisign.epp.exception.EPPException;
-import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
 /**
@@ -171,63 +170,6 @@ public class EPPLaunchTst extends TestCase {
 		super(name);
 	}
 
-	/**
-	 * Read and validate the active SMD's.
-	 */
-	public void testActiveSMDs() {
-		EPPCodecTst.printStart("testActiveSMDs");
-
-		// Validate the active SMD's
-		File activeSMDDir = new File(smdsDir + "/smd-active");
-
-		if (activeSMDDir.exists() && activeSMDDir.isDirectory()) {
-
-			InputStream smdStream = null;
-
-			File[] activeSMDFiles = activeSMDDir
-					.listFiles(new SMDFilenameFilter());
-
-			for (int i = 0; i < activeSMDFiles.length; i++) {
-				try {
-					smdStream = new FileInputStream(activeSMDFiles[i]);
-				}
-				catch (FileNotFoundException e1) {
-					Assert.fail("testActiveSMDs(): Error opening SMD \""
-							+ activeSMDFiles[i].getName() + "\"");
-				}
-
-				EPPSignedMark signedMark = null;  
-
-				try {
-					signedMark = new EPPEncodedSignedMark(smdStream);
-				}
-				catch (EPPException e) {
-					e.printStackTrace();
-					Assert.fail("testActiveSMDs(): Error decoding \""
-							+ activeSMDFiles[i].getName() + "\": " + e);
-				}
-
-				// Validate the DSIG of the SMD
-				if (!signedMark.validate(pkixParameters)) {
-					Assert.fail("testActiveSMDs(): Error validating \""
-							+ activeSMDFiles[i].getName() + "\"");
-				}
-
-				// Signed Mark is revoked?
-				if (smdRevocationList.isRevoked(signedMark)) {
-					Assert.fail("testActiveSMDs(): SMD \""
-							+ activeSMDFiles[i].getName() + "\" is revoked");
-
-				}
-				
-				System.out.println("testActiveSMDs: Success with SMD \""
-						+ activeSMDFiles[i].getName() + "\"");
-			}
-
-		}
-
-		EPPCodecTst.printEnd("testActiveSMDs");
-	}
 	
 	
 	/**
@@ -997,6 +939,8 @@ public class EPPLaunchTst extends TestCase {
 		theExt.addCheckResult(new EPPLaunchCheckResult("example1.tld", false));
 		theExt.addCheckResult(new EPPLaunchCheckResult("example2.tld", true,
 				"2013041500/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000001"));
+		theExt.addCheckResult(new EPPLaunchCheckResult("example2.tld", true,
+				"2013111200/2/6/9/rJ1NrDO92vDsAzf7EQzgjX4R0000000002", "tmch"));
 
 		theResponse.addExtension(theExt);
 
@@ -1060,9 +1004,9 @@ public class EPPLaunchTst extends TestCase {
 		EPPLaunchCreate createExt = new EPPLaunchCreate(new EPPLaunchPhase(
 				EPPLaunchPhase.PHASE_SUNRISE));
 
-		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AC"));
+		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AC", "sample1"));
 		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AD"));
-		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AE"));
+		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AE", "sample2"));
 
 		theCommand.setExtensions(null);
 		theCommand.addExtension(createExt);
@@ -1173,7 +1117,7 @@ public class EPPLaunchTst extends TestCase {
 		theCommand.setExtensions(null);
 		theCommand.addExtension(new EPPLaunchCreate(new EPPLaunchPhase(
 				EPPLaunchPhase.PHASE_SUNRISE), new EPPLaunchCodeMark(
-				"49FD46E6C4B45C55D4AC", mark)));
+				"49FD46E6C4B45C55D4AC", "sample", mark)));
 
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
@@ -1184,9 +1128,9 @@ public class EPPLaunchTst extends TestCase {
 				EPPLaunchPhase.PHASE_SUNRISE));
 
 		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AC",
-				mark));
+				"sample1", mark));
 		createExt.addCodeMark(new EPPLaunchCodeMark("49FD46E6C4B45C55D4AD",
-				mark));
+				"sample2", mark));
 
 		theCommand.setExtensions(null);
 		theCommand.addExtension(createExt);
@@ -1211,6 +1155,25 @@ public class EPPLaunchTst extends TestCase {
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
 
+		
+		// Test create command with mix of sunrise create model and claims
+		// create model with validatorID
+		theCommand.setExtensions(null);
+		createExt = new EPPLaunchCreate(new EPPLaunchPhase(
+				EPPLaunchPhase.PHASE_CUSTOM, "non-tmch-sunrise"),
+				EPPLaunchCreate.TYPE_APPLICATION);
+
+		createExt.addCodeMark(new EPPLaunchCodeMark(mark));
+		createExt.setNotice(new EPPLaunchNotice("49FD46E6C4B45C55D4AC",
+				new Date(), new Date(), "custom"));
+
+		theCommand.setExtensions(null);
+		theCommand.addExtension(createExt);
+
+		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
+		System.out.println(commandStats);
+		
+		
 		EPPCodecTst.printEnd("testLaunchCreateCodeMark");
 	}
 
@@ -1487,14 +1450,26 @@ public class EPPLaunchTst extends TestCase {
 			theCommand.setContacts(contacts);
 		}
 
-		// Test create command for sunrise create using the notice information
+		// Test create command for claims create using the notice information
 		theCommand.addExtension(new EPPLaunchCreate(new EPPLaunchPhase(
-				EPPLaunchPhase.PHASE_SUNRISE), new EPPLaunchNotice(
+				EPPLaunchPhase.PHASE_CLAIMS), new EPPLaunchNotice(
 				"49FD46E6C4B45C55D4AC", new Date(), new Date()),
 				EPPLaunchCreate.TYPE_APPLICATION));
 
 		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
 		System.out.println(commandStats);
+		
+		theCommand.setExtensions(null);
+		
+		// Test create command for claims create using the notice information and validatorID
+		theCommand.addExtension(new EPPLaunchCreate(new EPPLaunchPhase(
+				EPPLaunchPhase.PHASE_CLAIMS), new EPPLaunchNotice(
+				"49FD46E6C4B45C55D4AC", new Date(), new Date(), "tmch"),
+				EPPLaunchCreate.TYPE_REGISTRATION));
+
+		commandStats = EPPCodecTst.testEncodeDecode(theCommand);
+		System.out.println(commandStats);
+		
 
 		EPPCodecTst.printEnd("testLaunchCreateNotice");
 	}
@@ -1678,6 +1653,63 @@ public class EPPLaunchTst extends TestCase {
 	}
 
 	
+	/**
+	 * Read and validate the active SMD's.
+	 */
+	public void testActiveSMDs() {
+		EPPCodecTst.printStart("testActiveSMDs");
+
+		// Validate the active SMD's
+		File activeSMDDir = new File(smdsDir + "/smd-active");
+
+		if (activeSMDDir.exists() && activeSMDDir.isDirectory()) {
+
+			InputStream smdStream = null;
+
+			File[] activeSMDFiles = activeSMDDir
+					.listFiles(new SMDFilenameFilter());
+
+			for (int i = 0; i < activeSMDFiles.length; i++) {
+				try {
+					smdStream = new FileInputStream(activeSMDFiles[i]);
+				}
+				catch (FileNotFoundException e1) {
+					Assert.fail("testActiveSMDs(): Error opening SMD \""
+							+ activeSMDFiles[i].getName() + "\"");
+				}
+
+				EPPSignedMark signedMark = null;  
+
+				try {
+					signedMark = new EPPEncodedSignedMark(smdStream);
+				}
+				catch (EPPException e) {
+					e.printStackTrace();
+					Assert.fail("testActiveSMDs(): Error decoding \""
+							+ activeSMDFiles[i].getName() + "\": " + e);
+				}
+
+				// Validate the DSIG of the SMD
+				if (!signedMark.validate(pkixParameters)) {
+					Assert.fail("testActiveSMDs(): Error validating \""
+							+ activeSMDFiles[i].getName() + "\"");
+				}
+
+				// Signed Mark is revoked?
+				if (smdRevocationList.isRevoked(signedMark)) {
+					Assert.fail("testActiveSMDs(): SMD \""
+							+ activeSMDFiles[i].getName() + "\" is revoked");
+
+				}
+				
+				System.out.println("testActiveSMDs: Success with SMD \""
+						+ activeSMDFiles[i].getName() + "\"");
+			}
+
+		}
+
+		EPPCodecTst.printEnd("testActiveSMDs");
+	}
 	
 
 	/**
@@ -1734,6 +1766,7 @@ public class EPPLaunchTst extends TestCase {
 		EPPCodecTst.printEnd("testRevokedCertSMDs");
 	}
 
+
 	/**
 	 * Read and ensure invalid SMD's do not pass validation.
 	 */
@@ -1847,7 +1880,7 @@ public class EPPLaunchTst extends TestCase {
 
 		EPPCodecTst.printEnd("testRevokedSMDs");
 	}
-
+	
 	/**
 	 * JUNIT <code>setUp</code> method, which sets the default client Id to
 	 * "theRegistrar" and initializes the <code>EPPDomainMapFactory</code> with
